@@ -25,46 +25,39 @@ class DescribeSagVbrRelationsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Smartag', '2018-03-13', 'DescribeSagVbrRelations','smartag')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_VbrInstanceIdss(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_VbrInstanceIdss(self): # RepeatList
 		return self.get_query_params().get('VbrInstanceIds')
 
-	def set_VbrInstanceIdss(self, VbrInstanceIdss):
-		for depth1 in range(len(VbrInstanceIdss)):
-			if VbrInstanceIdss[depth1] is not None:
-				self.add_query_param('VbrInstanceIds.' + str(depth1 + 1) , VbrInstanceIdss[depth1])
-
-	def get_VbrRegionId(self):
+	def set_VbrInstanceIdss(self, VbrInstanceIds):  # RepeatList
+		pass
+	def get_VbrRegionId(self): # String
 		return self.get_query_params().get('VbrRegionId')
 
-	def set_VbrRegionId(self,VbrRegionId):
-		self.add_query_param('VbrRegionId',VbrRegionId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_VbrRegionId(self, VbrRegionId):  # String
+		self.add_query_param('VbrRegionId', VbrRegionId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
