@@ -25,52 +25,44 @@ class DescribeUserFlowStatisticsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Smartag', '2018-03-13', 'DescribeUserFlowStatistics','smartag')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_UserNamess(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_UserNamess(self): # RepeatList
 		return self.get_query_params().get('UserNames')
 
-	def set_UserNamess(self, UserNamess):
-		for depth1 in range(len(UserNamess)):
-			if UserNamess[depth1] is not None:
-				self.add_query_param('UserNames.' + str(depth1 + 1) , UserNamess[depth1])
-
-	def get_ResourceOwnerAccount(self):
+	def set_UserNamess(self, UserNames):  # RepeatList
+		pass
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_StatisticsDate(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_StatisticsDate(self): # String
 		return self.get_query_params().get('StatisticsDate')
 
-	def set_StatisticsDate(self,StatisticsDate):
-		self.add_query_param('StatisticsDate',StatisticsDate)
-
-	def get_OwnerId(self):
+	def set_StatisticsDate(self, StatisticsDate):  # String
+		self.add_query_param('StatisticsDate', StatisticsDate)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_SmartAGId(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_SmartAGId(self): # String
 		return self.get_query_params().get('SmartAGId')
 
-	def set_SmartAGId(self,SmartAGId):
-		self.add_query_param('SmartAGId',SmartAGId)
\ No newline at end of file
+	def set_SmartAGId(self, SmartAGId):  # String
+		self.add_query_param('SmartAGId', SmartAGId)
